
#-----------------------------------------------------------------------
# README
#-----------------------------------------------------------------------
#
#
#
#-----------------------------------------------------------------------
# CHANGES 
#-----------------------------------------------------------------------
#
# 2001-02-10  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Initial function file written for rcf version 5.1.
#
#-----------------------------------------------------------------------
# FUNCTION
#-----------------------------------------------------------------------

Accept_Hostports () {
	#
	# This function expects each host to have an accompanying port number.
	#
	# Syntax:
	#   Accept_Hostports [local|remote] {protocol} {description} {hosts and ports)
	#
	# Examples:
	#   Accept_Hostports local tcp "HTTP" any/0 www
	#   Accept_Hostports local tcp "My Game" first.friend.com 1234:1240 1666, second.friend.com 1234
	#
	LOCATION="`echo $1|tr -s '[A-Z]' '[a-z]'`"

	case $LOCATION in
		local|remote)
			:
			;;
		*)	echo "WARNING: Accept_Hostports function needs [local|remote] as first"
			echo "parameter since v5.1."
			return
			;;
	esac

	PROTOCOL="$2"
	SERVDESC="$3"
	shift 3

	# Make sure there's at least one host ($1) and one port ($2)
	#
	if [ "$2" ]
	then
		LCASE_PROTOCOL="`echo $PROTOCOL|tr -s '[A-Z]' '[a-z]'`"
		HOSTPORTS="`echo $*|sed 's/,/ *separator* /g'`"
		HOST=""

		for FIELD in $HOSTPORTS
		do
			if [ "$FIELD" = "*separator*" ]
			then
				HOST=""
			elif [ ! "$HOST" ]
			then
				HOST="$FIELD"
			else
				PORT="$FIELD"
				
				# Display the port number only if it's numerical.
				[ "`echo $PORT|grep '^[0-9][0-9]*'|wc -l`" -gt 0 ] && SHOW_PORT=" Port# ${PORT}" || SHOW_PORT=""

				case $LCASE_PROTOCOL in
					tcp)	SYNOPT="! -y";;
					*)		SYNOPT="";;
				esac

				case $LOCATION in
					local)
						echo "Accept $INTOPT $IPADDR ${SERVDESC}${SHOW_PORT}/$LCASE_PROTOCOL <- $HOST $LOG_MSG"
						ipchains -A $INCHAIN  -j ACCEPT -p $LCASE_PROTOCOL \
							-s $HOST $UNPRIVPORTS -d $IPADDR $PORT $LOG
						ipchains -A $OUTCHAIN -j ACCEPT -p $LCASE_PROTOCOL $SYNOPT \
							-s $IPADDR $PORT -d $HOST $UNPRIVPORTS $LOG
						;;
					remote)
						echo "Accept $INTOPT $IPADDR/$LCASE_PROTOCOL -> $HOST ${SERVDESC}${SHOW_PORT} $LOG_MSG"

						# If this is a rule for a cluster, we need access *through* the
						# interface. This means the INCHAIN/OUTCHAIN variables must be 
						# reversed.
						if [ "$CLUSTER_NAME" ]
						then
							ipchains -A $OUTCHAIN -j ACCEPT -p $LCASE_PROTOCOL $SYNOPT \
								-s $HOST $PORT -d $IPADDR $UNPRIVPORTS $LOG
							ipchains -A $INCHAIN  -j ACCEPT -p $LCASE_PROTOCOL \
								-s $IPADDR $UNPRIVPORTS -d $HOST $PORT $LOG
						else
							ipchains -A $INCHAIN  -j ACCEPT -p $LCASE_PROTOCOL $SYNOPT \
								-s $HOST $PORT -d $IPADDR $UNPRIVPORTS $LOG
							ipchains -A $OUTCHAIN -j ACCEPT -p $LCASE_PROTOCOL \
								-s $IPADDR $UNPRIVPORTS -d $HOST $PORT $LOG
						fi
						;;
				esac
			fi
		done
	fi
}

