
#-----------------------------------------------------------------------
# README
#-----------------------------------------------------------------------
#
#
#
#-----------------------------------------------------------------------
# CHANGES 
#-----------------------------------------------------------------------
#
# 2001-02-10  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Initial function file written for rcf version 5.1.
#
#-----------------------------------------------------------------------
# FUNCTION
#-----------------------------------------------------------------------

Config_Options () {
	#
	# $1: Actions (enable, accept, deny, etc.)
	# $2: Interface Type (private|public|real_private|real_public)
	# $3: Service (telnet, etc.)
	# $4: Type (servers, clients, hosts, etc.)
	# $5: Default Value (syntax: "action = value")
	#
	LCASE_ACTIONS="`echo $1|tr '[A-Z]' '[a-z]'`"
	LCASE_TYPES="`echo $2|tr '[A-Z]' '[a-z]'`"

	rm -f ${CONF}.options.tmp
	touch ${CONF}.options.tmp
	chmod 600 ${CONF}.options.tmp
	
	MAX_OPTION_LEN="0"

	for LCASE_TYPE in $LCASE_TYPES
	do
		if [ "`echo $2|egrep -c '^real_'`" -gt "0" ]
		then
			ONLY_REAL="yes"
			LCASE_TYPE="`echo $LCASE_TYPE|sed 's/^real_\(.*\)$/\1/'`"
		else
			ONLY_REAL="no"
		fi

		UCASE_TYPE="`echo $LCASE_TYPE|tr '[a-z]' '[A-Z]'`"
		eval INTERFACES=\"\$${UCASE_TYPE}_INTERFACES\"
	
		for INTERFACE in $INTERFACES
		do
			# skip any virtual interface if necessary
			[ "`echo $INTERFACE|egrep -c ':'`" -gt "0" -a "$ONLY_REAL" = "yes" ] && continue
	
			UCASE_INTERFACE="`echo $INTERFACE|tr '[a-z]' '[A-Z]'|tr ':-' '_'`"
	
			# check to see if cluster names have been defined for this interface
			eval CLUSTER_NAMES=\"\$${UCASE_TYPE}_${UCASE_INTERFACE}_CLUSTER_NAMES\"
	
			INTERFACE_FIELDS="$INTERFACE"
			for CLUSTER_NAME in $CLUSTER_NAMES
			do
				INTERFACE_FIELDS="$INTERFACE_FIELDS ${INTERFACE}:${CLUSTER_NAME}"
			done
	
			# For regular interfaces, the INTERFACE_FIELDS variable contains only
			# a single interface name. For DMZs, the interface has been joined with
			# cluster names (i.e. "eth3:webservers eth3:ftpservers", etc.).
			#
			for INTERFACE_FIELD in $INTERFACE_FIELDS
			do
				CLUSTER_MATCH="`echo \"$INTERFACE_FIELD\"|egrep \"^${INTERFACE}:.*\$\"`"

				for ACTION in $LCASE_ACTIONS
				do
					# ******** skip 'forward' actions for D/MZ clusters ********
					[ "$ACTION" = "forward" -a "$CLUSTER_MATCH" ] && continue
	
					VAR="`echo ${ACTION}-${INTERFACE_FIELD}-${3}-${4}|tr '[A-Z]' '[a-z]'|tr '_' '-'`"
					VALUE="`echo ${ACTION}_${INTERFACE_FIELD}_${3}_${4}|tr '[a-z]' '[A-Z]'|tr ':-' '_'`"
			
					if [ ! "`Defined $VALUE`" -a "`expr \"$5\" : \"${ACTION}_${LCASE_TYPE} \"`" -gt "0" ]
					then
						DEFAULT_VALUE="`echo $5|sed -n "s/^${ACTION}_${LCASE_TYPE}  *=  *\(.*\)$/\1/p\"`"
						eval : \${$VALUE:=\"$DEFAULT_VALUE\"}
					fi
	
					OPTION_LEN="`expr length $VAR`"
					[ "$OPTION_LEN" -gt "$MAX_OPTION_LEN" ] && MAX_OPTION_LEN="$OPTION_LEN"
	
					eval echo "${VAR}=\$${VALUE}" >> ${CONF}.options.tmp
				done
			done
		done
	done

	unset INTERFACE_FIELDS INTERFACE_FIELD
	unset INTERFACES INTERFACE CLUSTER_NAMES CLUSTER_NAME
	unset LCASE_ACTIONS LCASE_TYPES UCASE_TYPE
	
	if [ "$MAX_OPTION_LEN" -gt "0" ]
	then
		gawk -v LEN="$MAX_OPTION_LEN" 'BEGIN { FS="="; }
			{ printf("%" LEN "s = %s\n", $1, $2); }
			END { print ""; }' ${CONF}.options.tmp >> "${CONF}.tmp"
	fi
	unset MAX_OPTION_LEN

	rm -f ${CONF}.options.tmp
}

