
#-----------------------------------------------------------------------
# README
#-----------------------------------------------------------------------
#
#
#
#-----------------------------------------------------------------------
# CHANGES 
#-----------------------------------------------------------------------
#
# 2001-02-10  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Initial function file written for rcf version 5.1.
#
#-----------------------------------------------------------------------
# FUNCTION
#-----------------------------------------------------------------------

Security_Check () {
	echo ""
	echo "Performing Security Checks..."

	# Before calling this function, the PATH was prefixed with the standard
	# binary directories. This minimizes the chance of finding a bad egrep
	# or sed which are used here.
	#
	if [ "`echo $PATH | egrep -c ':\.(:|/|$)'`" -gt 0 ]
	then
		FAILED="yes"
		cat <<EOF

Your PATH variable contains relative directories (doesn't start with '/').
For security reasons, you should remove these directories from your PATH
permanently.
EOF
		echo ""
		[ "$ORIGINAL_PATH" ] && echo "Original PATH=${PATH}"
		PATH="`echo $PATH|sed 's/:[^\/][^:]*:*/:/g'|sed 's/:$//'`"
		export PATH
		echo "   Fixed PATH=${PATH}"
	fi

	# Now that we've potentially broken the PATH variable <smile>, make
	# sure we can still get at all the binaries we'll need.
	#
	for BIN in \
		gawk \
		basename \
		cat \
		chmod \
		cp \
		dirname \
		egrep \
		find \
		grep \
		ifconfig \
		ipchains \
		modprobe \
		mv \
		netstat \
		route \
		sed \
		sort \
		tr \
		uniq \
		wc
	do
		if [ ! "`which $BIN 2>/dev/null`" ]
		then
			[ ! "$FAILED" ] && echo ""; FAILED="yes"
			echo "Unable to locate $BIN in any PATH directory!"
		fi
	done

	if [ "$SECURITY_FILE_CHECK" != "no" ]
	then
		DIR_PERM="0700"
		for FILE_DIR in $0 $CONF ${CONF}.bak ${GROUP_DIR} ${MODULE_DIR} ${FUNCTION_DIR}
		do
			case $FILE_DIR in
				$0)	FILE_PERM="0700" ;;
				*)	FILE_PERM="0600" ;;
			esac
			[ -e "$FILE_DIR" ] && \
				for FILE in `find "$FILE_DIR" -follow \
				\( ! -group root -o ! -user root -o \
				\( -type f -a ! -perm "$FILE_PERM" \) \) -print`
			do
				FAILED="yes"
				cat <<EOF

The owners and/or permissions for ${FILE} are incorrect.
Please execute the following commands:
	chmod $FILE_PERM $FILE
	chown root:root $FILE
EOF
			done
			[ -e "$FILE_DIR" ] && \
				for FILE in `find "$FILE_DIR" -follow \
				\( ! -group root -o ! -user root -o \
				\( -type d -a ! -perm "$DIR_PERM" \) \) -print`
			do
				FAILED="yes"
				cat <<EOF

The owners and/or permissions for ${FILE} are incorrect.
Please execute the following commands:
	chmod $DIR_PERM $FILE
	chown root:root $FILE
EOF
			done
		done
		unset DIR_PERM FILE_PERM
	fi

	if [ "$FAILED" ]
	then
		echo ""
		echo "These problems must be addressed before running `basename $0` again."
		echo ""
		exit 1
	fi
}

