
#-----------------------------------------------------------------------
# README
#-----------------------------------------------------------------------
#
#
#
#-----------------------------------------------------------------------
# CHANGES 
#-----------------------------------------------------------------------
#
# 2001-02-10  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Initial function file written for rcf version 5.1.
#
#-----------------------------------------------------------------------
# FUNCTION
#-----------------------------------------------------------------------

Service_Rules () {

	INTERFACE_TYPE="$1"
	INTERFACE_MODE="$2"

	# Illegal/malformed addresses must be blocked BEFORE opening
	# services which use any/0 (like http, smtp, etc.).
	#
	# Private networks are denied in a MODULE. This is because
	# some ISPs use private addresses on their network for DHCP
	# services. Private networks are blocked after DHCP client
	# rules are implemented.

	if [ ! "$CLUSTER_NAME" -a "$VIRTUAL" = "no" ]
	then
		Illegal_Malformed_Address_Rules

		if [ "$INTERFACE_TYPE" = "public" ]
		then
			all_private_subnets="`{
				for private_interface in lo $PRIVATE_INTERFACES $MZ_INTERFACES
				do
					Get_Interface_Vars "$private_interface" "PRIVATE"
					Device_Subnets PRIVATE
				done
				unset private_interface
			} | sort | uniq`"

			for private_subnet in $all_private_subnets
			do
				echo "Reject $INTERFACE Stuffed Masquerading $private_subnet -> $ANY (logged)"
				ipchains -A $OUTCHAIN -j REJECT -s $private_subnet -d $ANY -l

				# Don't allow private interface IPs from/to public interfaces.
				# All traffic should be masqueraded in these cases. Private IPs
				# are OK for DMZ interfaces.
				#
				echo "Deny $INTERFACE IP Spoofing $ANY <- $private_subnet (logged)"
				ipchains -A $INCHAIN -j DENY -s $private_subnet -d $ANY -l

				echo "Reject $INTERFACE Stuffed Routing $ANY -> $private_subnet (logged)"
				ipchains -A $OUTCHAIN -j REJECT -s $ANY -d $private_subnet -l
			done
			unset private_subnet

			[ "$IANA_RESERVED_NETWORKS" ] && echo "Deny $INTERFACE <- IANA Reserved Networks"
			for reserved_network in $IANA_RESERVED_NETWORKS
			do
				ipchains -A $INCHAIN -j DENY -p all -s $reserved_network -d $ANY $ACTION_LOG
			done
			unset reserved_network
		fi
	fi

	#-------------------------------------------------------------------
	# Service Modules
	#-------------------------------------------------------------------

	for MODULE in ${MODULE_DIR}/${INTERFACE_TYPE}/services/[0-9][0-9][0-9]-*
	do
		if [ -f "$MODULE" ]
		then
			MODE="$INTERFACE_MODE"	# may be used in module code
			MODULE_MODE="`sed -n 's/^#[mM]#  *\([ 0-9]*\)/\1/p' $MODULE`"
			if [ ! "$MODULE_MODE" -o "`echo $MODULE_MODE|grep \"$INTERFACE_MODE\"|wc -l`" -gt "0" ]
			then
				. "$MODULE" "$MODULE"
			fi
			unset MODULE_MODE
		fi
	done

	#--------------------------------------------------------------------
	# Misc. UDP and TCP Ports
	#--------------------------------------------------------------------
	# The "HOSTPORTS" variables have a different structure -- we don't 
	# need a for-loop here for host names.
	#--------------------------------------------------------------------

	Accept_Hostports local tcp "" `Option_Value accept $INTERFACE tcp hostports`
	Accept_Hostports local udp "" `Option_Value accept $INTERFACE udp hostports`

	unset INTERFACE_TYPE INTERFACE_MODE
}

