
#-----------------------------------------------------------------------
# README
#-----------------------------------------------------------------------
#
#
#
#-----------------------------------------------------------------------
# CHANGES 
#-----------------------------------------------------------------------
#
# 2001-03-04  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Added for-loop to check if all essential variables have
#             been set.
# 2001-02-10  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Initial function file written for rcf version 5.1.
#
#-----------------------------------------------------------------------
# FUNCTION
#-----------------------------------------------------------------------

Set_Interface_Vars () {
	#
	# syntax: Set_Interface_Vars LOOPBACK PUBLIC PRIVATE DMZ MZ
	#
	for ARG_INTERFACE_TYPE in $*
	do
		ARG_INTERFACE_TYPE=`echo $ARG_INTERFACE_TYPE|tr '[a-z]' '[A-Z]'`
		eval ARG_INTERFACES=\"\$${ARG_INTERFACE_TYPE}_INTERFACES\"

		for ARG_INTERFACE in $ARG_INTERFACES
		do
			UCASE_INTERFACE=`echo $ARG_INTERFACE|tr '[a-z]' '[A-Z]'|tr ':-' '_'`

			IPADDR=""
			NETMASK=""
			NETWORK=""
			BROADCAST=""
			GATEWAY=""

			if [ -f /etc/dhcpc/dhcpcd-${ARG_INTERFACE}.info ]
			then
				echo "Reading /etc/dhcpc/dhcpcd-${ARG_INTERFACE}.info..."
				eval `cat /etc/dhcpc/dhcpcd-${ARG_INTERFACE}.info`
			fi

			# Sample content for /etc/dhcpc/dhcpcd-eth1.info:
			#
			#	BROADCAST=255.255.255.255
			#	DHCPCHADDR=00:50:BA:B0:64:21
			#	DHCPGIADDR=0.0.0.0
			#	DHCPSHADDR=00:90:BF:5A:38:52
			#	DHCPSIADDR=0.0.0.0
			#	DHCPSID=24.200.243.150
			#	DHCPSNAME=
			#	DNS=205.151.222.250,205.151.222.251
			#	DOMAIN=videotron.ca
			#	GATEWAY=24.200.96.1
			#	INTERFACE=eth1
			#	IPADDR=24.200.96.155
			#	LEASETIME=60538
			#	NETMASK=255.255.255.0
			#	NETWORK=24.200.96.0
			#	REBINDTIME=52970
			#	RENEWALTIME=30269
	
			[ ! "$IPADDR" ] && IPADDR="`ifconfig $ARG_INTERFACE|sed -n 's/.* addr:\([0-9\.]*\) .*/\1/p'`"
	
			[ ! "$NETMASK" ] && NETMASK="`ifconfig $ARG_INTERFACE|sed -n 's/.* Mask:\([0-9\.]*\)$/\1/p'`"
	
			[ ! "$NETWORK" ] && NETWORK="`netstat -nre|sed -n \
					"s/\([0-9][0-9\.]*\)  *0\.\0\.\0\.0  *${NETMASK}  *U  *.* ${ARG_INTERFACE}\$/\1/p\"|xargs`"

			[ "`expr \"$NETWORK\" : \"[0-9\.]* [0-9]\"`" -gt "0" -o ! "$NETWORK" ] \
				&& NETWORK="`Subnet_Calc -n $IPADDR $NETMASK`"

			[ ! "$BROADCAST" ] && BROADCAST="`ifconfig $ARG_INTERFACE|sed -n 's/.* Bcast:\([0-9\.]*\) .*/\1/p'`"

			[ ! "$BROADCAST" ] && BROADCAST="`Subnet_Calc -b $IPADDR $NETMASK`"

			[ ! "$GATEWAY" ] && GATEWAY=`route -n|egrep -A 4 "0\.0\.0\.0 .* UG .* $ARG_INTERFACE"| \
				egrep -v " 10\." | gawk '{ print $2 }'`

			# Verify that we have all the essential variables set.
			for variable_name in IPADDR NETMASK NETWORK BROADCAST
			do
				eval variable_value=\"\$$variable_name\"
				[ ! "$variable_value" ] && echo "WARNING: Unable to determine $variable_name for ${ARG_INTERFACE}."
			done
			unset variable_name variable_value
			
			eval ${UCASE_INTERFACE}_IPADDR=\"$IPADDR\"
			eval ${UCASE_INTERFACE}_NETMASK=\"$NETMASK\"
			eval ${UCASE_INTERFACE}_NETWORK=\"$NETWORK\"
			eval ${UCASE_INTERFACE}_BROADCAST=\"$BROADCAST\"
			eval ${UCASE_INTERFACE}_GATEWAY=\"$GATEWAY\"
			eval ${UCASE_INTERFACE}_INCHAIN=\"`echo ${ARG_INTERFACE}|sed -n 's/^\([^:]*\).*$/\1/p'`i\"
			eval ${UCASE_INTERFACE}_OUTCHAIN=\"`echo ${ARG_INTERFACE}|sed -n 's/^\([^:]*\).*$/\1/p'`o\"
		done
	done
	unset ARG_INTERFACE_TYPE ARG_INTERFACES ARG_INTERFACE UCASE_INTERFACE
}

