
#-----------------------------------------------------------------------
# README
#-----------------------------------------------------------------------
#
# Return the network and/or broadcast addresses using ipcalc or perl.
# Syntax: Subnet_Calc -[n|b|nb] {IP} {Netmask}
#
#-----------------------------------------------------------------------
# CHANGES 
#-----------------------------------------------------------------------
#
# 2001-03-04  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Added check and use of "which" binary instead of built-in
#             shell version.
# 2001-03-03  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Added check for executable bit on output from "which".
# 2001-02-11  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Added check for ipcalc executable which comes standard on
#             Red Hat installations.
# 2001-02-10  Jean-Sebastien Morisset <jsmoriss@mvlan.net>
#             Initial function file written for rcf version 5.1.
#
#-----------------------------------------------------------------------
# FUNCTION
#-----------------------------------------------------------------------

Subnet_Calc () {
	
	# Determine the path to the which binary. Some linux installations
	# use a built-in which by default which doesn't behave as expected.
	#
	which_bin="`which which 2>/dev/null`"

	# ipcalc is found on Red Hat and perhaps others.
	#
	if [ -x "`$which_bin ipcalc 2>/dev/null`" ]
	then
		case $1 in
			-n)
				ipcalc --silent --hostname $2 --netmask $3 --network|sed -n 's/^NETWORK=\(.*\)$/\1/p'
				;;
			-b)
				ipcalc --silent --hostname $2 --netmask $3 --broadcast|sed -n 's/^BROADCAST=\(.*\)$/\1/p'
				;;
			-nb)
				echo -n "`ipcalc --silent --hostname $2 --netmask $3 --network|sed -n 's/^NETWORK=\(.*\)$/\1/p'`"
				echo " `ipcalc --silent --hostname $2 --netmask $3 --broadcast|sed -n 's/^BROADCAST=\(.*\)$/\1/p'`"
				;;
		esac
	elif [ -x "`$which_bin perl 2>/dev/null`" ]
	then
		perl -e '
			($option, $ip, $mask) = @ARGV;
			$packedip = pack("C4", split(/\./, $ip));
			$packedmask = pack("C4", split(/\./, $mask));
			$packednet = $packedip & $packedmask;
			$packedbroadcast = $packedip | ~ $packedmask;

			@net = unpack("C4", $packednet);
			$net = join ".", @net;

			@broadcast = unpack("C4", $packedbroadcast);
			$broadcast = join ".", @broadcast;

			if ($option eq "-n") { print $net, "\n"; }
			if ($option eq "-b") { print $broadcast, "\n"; }
			if ($option eq "-nb") { print $net, " ", $broadcast, "\n"; }
		' -- $1 $2 $3
	fi

	unset which_bin
}

